![Codecov](https://codecov.io/gh/IliyaZinoviev/round-utils/branch/master/graph/badge.svg)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
# Round utils
This package provides functions to round numbers up to a multiplicity of a pointed step.
Float value's rounded by literal representation.
# Example of usage

```python
>>> import round_utils

>>> round_utils.round_up(32.333, 0.02)
32.34

>>> round_utils.round_down(32.333, 0.02)
32.32
```


